@@ -20,18 +20,28 @@ calcPRT <- function(modelPredictions, yValues) {
   modelPredictions <- modelPredictions[ord]
   precision <- cumsum(yValues)/seq_len(length(yValues)) # Precision
   recall <- cumsum(yValues)/max(1,sum(yValues))      # TPR/Recall
+
+  notY <- 1 - yValues # falses
+  fpr <- cumsum(notY)/max(1, sum(notY)) # (pred T AND actually F)/(all F)
+  specificity <- 1 - fpr
+
+
   data.frame(threshold = modelPredictions,
              precision = precision,
              enrichment = precision/prevalence,
-             recall = recall)
+             recall = recall,
+             sensitivity = recall,
+             false_positive_rate = fpr,
+             specificity = specificity)
 }
 
 
 
 #' Plot Precision-Recall or Enrichment-Recall as a function of threshold.
 #'
-#' Plot Precision-Recall or Enrichment-Recall as a function of threshold.
+#' Plot classifier performance metrics as a function of threshold.
 #'
+#'@details
 #' For a classifier, the precision is what fraction of predicted positives
 #' are true positives; the recall is what fraction of true positives the
 #' classifier finds, and the enrichment is the ratio of classifier precision to
@@ -39,32 +49,50 @@ calcPRT <- function(modelPredictions, yValues) {
 #' as a function of classifier score helps identify a score threshold that achieves
 #' an acceptable tradeoff between precision and recall, or enrichment and recall.
 #'
+#' In addition to precision/recall, \code{PRTPlot} can plot a number of other metrics:
+#'
+#' \itemize{
+#'   \item{precision: fraction of predicted positives that are true positives}
+#'   \item{recall: fraction of true positives that were predicted to be true}
+#'   \item{enrichment: ratio of classifier precision to prevalence of positive class}
+#'   \item{sensitivity: the same as recall (also known as the true positive rate)}
+#'   \item{specificity: fraction of true negatives to all negatives (or 1 - false_positive_rate)}
+#'   \item{false_positive_rate: fraction of negatives predicted to be true over all negatives}
+#' }
+#'
+#' For example, plotting sensitivity/false_positive_rate as functions of threshold will "unroll" an ROC Plot.
+#'
+#' Plots are in a single column, in the order specified by \code{plotvars}.
+#'
 #'
 #' @param frame data frame to get values from
-#' @param xvar name of the independent (input or model) column in frame
-#' @param truthVar name of the dependent (output or result to be modeled) column in frame
+#' @param predVar name of the column of predicted scores
+#' @param truthVar name of the column of actual outcomes in frame
 #' @param truthTarget value we consider to be positive
 #' @param title title to place on plot
 #' @param ...  no unnamed argument, added to force named binding of later arguments.
-#' @param plotvars variables to plot, must be at least one of "precision", "recall" and "enrichment". Defaults to c("precision", "recall")
+#' @param plotvars variables to plot, must be at least one of the measures listed below. Defaults to c("precision", "recall")
 #' @param thresholdrange range of thresholds to plot.
 #' @param linecolor line color for the plot
 #'
-#' @seealso \code{\link{PRPlot}}
+#' @seealso \code{\link{PRPlot}}, \code{\link{ROCPlot}}
 #'
 #' @examples
 #'
-#' set.seed(34903490)
-#' x = rnorm(50)
-#' y = 0.5*x^2 + 2*x + rnorm(length(x))
-#' frm = data.frame(x=x,y=y,yC=y>=as.numeric(quantile(y,probs=0.8)))
-#' frm$absY <- abs(frm$y)
-#' frm$posY = frm$y > 0
-#' frm$costX = 1
-#' WVPlots::PRTPlot(frm, "x", "yC", TRUE, title="Example Precision-Recall threshold plot")
+#' df <- iris
+#' df$isVersicolor <- with(df, Species=='versicolor')
+#' model = glm(isVersicolor ~ Petal.Length + Petal.Width + Sepal.Length + Sepal.Width,
+#'             data=df, family=binomial)
+#' df$pred = predict(model, newdata=df, type="response")
+#'
+#' WVPlots::PRTPlot(df, "pred", "isVersicolor", TRUE, title="Example Precision-Recall threshold plot")
+#'
+#' WVPlots::PRTPlot(df, "pred", "isVersicolor", TRUE,
+#'                  plotvars = c("sensitivity", "specificity", "false_positive_rate"),
+#'                  title="Sensitivity/specificity/FPR as functions of threshold")
 #'
 #' @export
-PRTPlot <- function(frame, xvar, truthVar, truthTarget, title,
+PRTPlot <- function(frame, predVar, truthVar, truthTarget, title,
                    ...,
                    plotvars = c("precision", "recall"),
                    thresholdrange = c(-Inf, Inf),
@@ -72,14 +100,14 @@ PRTPlot <- function(frame, xvar, truthVar, truthTarget, title,
                    ) {
   frame <- check_frame_args_list(...,
                                  frame = frame,
-                                 name_var_list = list(xvar = xvar, truthVar = truthVar),
+                                 name_var_list = list(predVar = predVar, truthVar = truthVar),
                                  title = title,
                                  funname = "WVPlots::PRPlot")
   outcol <- frame[[truthVar]]==truthTarget
   if(length(unique(outcol))!=2) {
     return(NULL)
   }
-  predcol <- frame[[xvar]]
+  predcol <- frame[[predVar]]
   prtFrame <- calcPRT(predcol,outcol)
 
   # mark not unbound
@@ -93,6 +121,9 @@ PRTPlot <- function(frame, xvar, truthVar, truthTarget, title,
                                      nameForNewValueColumn = "value",
                                      columnsToTakeFrom = plotvars)
 
+  # set the factor order to be the same as given in plotvars
+  prtlong$measure = factor(prtlong$measure, levels=plotvars)
+
   ggplot2::ggplot(prtlong, ggplot2::aes(x=threshold, y=value)) +
     ggplot2::geom_line(color=linecolor) +
     ggplot2::facet_wrap(~measure,
